@@ -9,9 +9,9 @@ use Exporter::Rinci qw(import);
 use IPC::System::Options 'system', 'readpipe', 'run', -log=>1;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-02-18'; # DATE
+our $DATE = '2023-04-13'; # DATE
 our $DIST = 'Clipboard-Any'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 my $known_clipboard_managers = [qw/klipper parcellite clipit xclip/];
 my $sch_clipboard_manager = ['str', in=>$known_clipboard_managers];
@@ -447,7 +447,15 @@ content is unchanged.
 _
     args => {
         %argspecopt_clipboard_manager,
-        content => {schema => 'str*', pos=>0, cmdline_src=>'stdin_or_args'},
+        content => {
+            schema => 'str*',
+            pos=>0,
+            cmdline_src=>'stdin_or_args',
+        },
+        tee => {
+            summary => 'If set to true, will output content back to STDOUT',
+            schema => 'bool*',
+        },
     },
     examples => [
         {
@@ -476,6 +484,7 @@ sub add_clipboard_content {
                "qdbus", "org.kde.klipper", "/klipper", "setClipboardContents", $args{content});
         my $exit_code = $? < 0 ? $? : $?>>8;
         return [500, "/klipper's setClipboardContents failed: $exit_code"] if $exit_code;
+        print $args{content} if $args{tee};
         return [200, "OK"];
     } elsif ($clipboard_manager eq 'parcellite') {
         # parcellite cli copies unknown options and stdin to clipboard history
@@ -491,6 +500,7 @@ sub add_clipboard_content {
         print $fh $args{content};
         close $fh
             or return [500, "xclip -i -selection primary failed (2): $!"];
+        print $args{content} if $args{tee};
         return [200, "OK"];
     }
 
@@ -512,7 +522,7 @@ Clipboard::Any - Common interface to clipboard manager functions
 
 =head1 VERSION
 
-This document describes version 0.010 of Clipboard::Any (from Perl distribution Clipboard-Any), released on 2023-02-18.
+This document describes version 0.011 of Clipboard::Any (from Perl distribution Clipboard-Any), released on 2023-04-13.
 
 =head1 DESCRIPTION
 
@@ -593,6 +603,10 @@ The default, when left undef, is to detect what clipboard manager is running.
 
 (No description)
 
+=item * B<tee> => I<bool>
+
+If set to true, will output content back to STDOUT.
+
 
 =back
 
